@@ -326,14 +326,14 @@ class ToolTabWidget(qt.QTabWidget):
         bg = "transparent"
         leftpadding = 8
         width = 24
-        self.setStyleSheet('''
-        QTabBar::tab:last {
-        background: %s;
-        margin: 2px 2px 3px 0px;
-        width: %s;
-        padding: 0px 0px 0px %spx;}
-        QTabBar::tab:last::hover {
-            background: %s;}''' % (bg, width, leftpadding, hbg))
+        #self.setStyleSheet('''
+        #QTabBar::tab:last {
+        #background: %s;
+        #margin: 2px 2px 3px 0px;
+        #width: %s;
+        #padding: 0px 0px 0px %spx;}
+        #QTabBar::tab:last::hover {
+        #    background: %s;}''' % (bg, width, leftpadding, hbg))
 
         self.set_offline_icon()
         self.show()
