@@ -121,8 +121,8 @@ class MainFrameRes(qt.QWidget):
         #parent.main_frame.viewport().setStyleSheet("#main_frame "
         #                                    "{background-color: #FFFFFF;}")
         #                                    #"{background-color: #E4E1E0;}")
-        self.setObjectName("Frame_Res")
-        self.setStyleSheet("#Frame_Res {background-color: %s;}"% get_system_rgb(self, ParameterWindow))
+        #self.setObjectName("Frame_Res")
+        #self.setStyleSheet("#Frame_Res {background-color: %s;}"% get_system_rgb(self, ParameterWindow))
         #self.setStyleSheet("#Frame_Res {background-color: green;}")
 #                           "QWidget {border: 1px solid red;}")
 
